@@ -1,12 +1,12 @@
 /*
-  $Id: Parser.h 15572 2013-01-07 14:59:11Z sloot $
+  $Id: Parser.h 17992 2015-01-21 14:07:56Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/Frog/trunk/include/frog/Parser.h $
 
-  Copyright (c) 2006 - 2013
+  Copyright (c) 2006 - 2015
   Tilburg University
 
   A Tagger-Lemmatizer-Morphological-Analyzer-Dependency-Parser for Dutch
- 
+
   This file is part of frog.
 
   frog is free software; you can redistribute it and/or modify
@@ -34,12 +34,12 @@
 class PyObjectRef {
  private:
   PyObject* ref;
-  
+
  public:
  PyObjectRef() : ref(0) {}
-  
+
  PyObjectRef(PyObject* obj) : ref(obj) {}
-  
+
   void assign(PyObject* obj) {
     // assume ref == 0, otherwhise call Py_DECREF
     if ( ref ){
@@ -47,13 +47,13 @@ class PyObjectRef {
     }
     ref = obj;
   }
-  
+
   operator PyObject* () {
     return ref;
   }
-  
+
   ~PyObjectRef() {
-    Py_XDECREF(ref);
+    //    Py_XDECREF(ref);
   }
 };
 
@@ -61,32 +61,35 @@ class PythonInterface {
  private:
   PyObjectRef module;
   PyObjectRef mainFunction;
-  
+
  public:
   PythonInterface();
   ~PythonInterface();
-  
+
   void parse( const std::string& depFile,
 	      const std::string& modFile,
 	      const std::string& dirFile,
 	      const std::string& maxDist,
 	      const std::string& inputFile,
 	      const std::string& outputFile);
-};  
+};
 
 struct parseData;
 
 class Parser {
  public:
- Parser():pairs(0),dir(0),rels(0),PI(0),isInit(false),keepIntermediate(false){};
+  Parser(TiCC::LogStream* logstream):pairs(0),dir(0),rels(0),PI(0),isInit(false),keepIntermediate(false) {
+    parseLog = new TiCC::LogStream(logstream, "parser-");
+  };
   ~Parser();
   bool init( const TiCC::Configuration& );
   void addDeclaration( folia::Document& doc ) const;
-  void Parse( const std::vector<folia::Word *>&, 
+  void Parse( const std::vector<folia::Word *>&,
 	      const std::string&, const std::string&, TimerBlock& );
-  void prepareParse( const std::vector<folia::Word *>&, 
+  void prepareParse( const std::vector<folia::Word *>&,
 		     const std::string&, parseData& );
   void createParserFile( const parseData& );
+  std::string getTagset() const { return tagset; };
  private:
   void createRelDir( const parseData& );
   void createPairs( const parseData& );
