@@ -1,8 +1,8 @@
 /*
-  $Id: cgn_tagger_mod.h 15572 2013-01-07 14:59:11Z sloot $
+  $Id: cgn_tagger_mod.h 17992 2015-01-21 14:07:56Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/Frog/trunk/include/frog/cgn_tagger_mod.h $
 
-  Copyright (c) 2006 - 2013
+  Copyright (c) 2006 - 2015
   Tilburg University
 
   This file is part of frog.
@@ -33,7 +33,7 @@
 
 class CGNTagger {
  public:
-  CGNTagger();
+  CGNTagger(TiCC::LogStream*);
   ~CGNTagger();
   bool init( const TiCC::Configuration& );
   void addDeclaration( folia::Document& ) const;
@@ -47,6 +47,7 @@ class CGNTagger {
   int debug;
   std::string tagset;
   std::string version;
+  Tokenizer::UnicodeFilter *filter;
 };
 
 #endif // CGN_TAGGER_MOD_H
