@@ -1,8 +1,8 @@
 /*
-  $Id: iob_tagger_mod.h 15572 2013-01-07 14:59:11Z sloot $
+  $Id: iob_tagger_mod.h 17992 2015-01-21 14:07:56Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/Frog/trunk/include/frog/iob_tagger_mod.h $
 
-  Copyright (c) 2006 - 2013
+  Copyright (c) 2006 - 2015
   Tilburg University
 
   This file is part of frog.
@@ -31,7 +31,7 @@
 
 class IOBTagger {
  public:
-  IOBTagger();
+  IOBTagger(TiCC::LogStream *);
   ~IOBTagger();
   bool init( const TiCC::Configuration& );
   void addDeclaration( folia::Document& ) const;
