@@ -1,8 +1,8 @@
 /*
-  $Id: mwu_chunker_mod.h 15877 2013-04-02 15:57:51Z sloot $
+  $Id: mwu_chunker_mod.h 17992 2015-01-21 14:07:56Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/Frog/trunk/include/frog/mwu_chunker_mod.h $
 
-  Copyright (c) 2006 - 2013
+  Copyright (c) 2006 - 2015
   Tilburg University
   
   This file is part of frog.
@@ -58,7 +58,7 @@ class mwuAna {
 class Mwu {
   friend std::ostream& operator<< (std::ostream&, const Mwu& );
  public:
-  Mwu();
+  Mwu(TiCC::LogStream*);
   ~Mwu();
   void reset();
   bool init( const TiCC::Configuration& );
