@@ -1,38 +1,34 @@
 /*
-  $Id: Frog-util.cxx 15572 2013-01-07 14:59:11Z sloot $
+  $Id: Frog-util.cxx 17992 2015-01-21 14:07:56Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/Frog/trunk/src/Frog-util.cxx $
 
-  Copyright (c) 2006 - 2013
+  Copyright (c) 2006 - 2015
   Tilburg University
 
   This file is part of frog
 
   frog is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by  
-  the Free Software Foundation; either version 3 of the License, or  
-  (at your option) any later version.  
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
   frog is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of  
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
-  GNU General Public License for more details.  
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-  You should have received a copy of the GNU General Public License  
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.  
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
       http://ilk.uvt.nl/software.html
   or send mail to:
       timbl@uvt.nl
-*/                                                                   
+*/
 
-#include <iostream>
-#include <fstream>
+#include <set>
 #include <string>
-#include <vector>
-#include <cstdlib>
 #include "config.h"
-#include "timbl/TimblAPI.h"
 #include "frog/Frog.h"
 
 #include <sys/types.h>
@@ -46,7 +42,7 @@ using namespace std;
 string prefix( const string& path, const string& fn ){
   if ( fn.find( "/" ) == string::npos ){
     // only append prefix when NO path is specified
-    return path + fn;
+    return path + "/" + fn;
   }
   return fn;
 }
@@ -62,7 +58,7 @@ bool existsDir( const string& dirName ){
 }
 
 void getFileNames( const string& dirName,
-		   const string& ext, 
+		   const string& ext,
 		   set<string>& fileNames ){
   DIR *dir = opendir( dirName.c_str() );
   if ( !dir )
@@ -90,23 +86,6 @@ void getFileNames( const string& dirName,
 
 #endif
 
-string& trim(string &str)  //3rd party function. TODO: test if utf-8 safe? (MvG)
-{
-    int i,j,start,end;
-
-    //ltrim
-    for (i=0; (str[i]!=0 && str[i]<=32); )
-        i++;
-    start=i;
-
-    //rtrim
-    for(i=0,j=0; str[i]!=0; i++)
-        j = ((str[i]<=32)? j+1 : 0);
-    end=i-j;
-    str = str.substr(start,end-start);
-    return str;
-}
-
 string getTime() {
   time_t Time;
   time(&Time);
