@@ -1,13 +1,13 @@
 /*
-  $Id: Parser.cxx 15912 2013-04-03 14:04:30Z sloot $
+  $Id: Parser.cxx 17992 2015-01-21 14:07:56Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/Frog/trunk/src/Parser.cxx $
 
-  Copyright (c) 2006 - 2013
+  Copyright (c) 2006 - 2015
   Tilburg University
 
   A Tagger-Lemmatizer-Morphological-Analyzer-Dependency-Parser for Dutch
   Version 0.04
- 
+
   This file is part of frog.
 
   frog is free software; you can redistribute it and/or modify
@@ -104,7 +104,7 @@ void PythonInterface::parse( const string& depFile,
 			     const string& maxDist,
 			     const string& inputFile,
 			     const string& outputFile ) {
-  
+
   PyObjectRef tmp = PyObject_CallFunction(mainFunction,
 					  (char *)"[s, s, s, s, s, s, s, s, s, s, s]",
 					  "--dep", depFile.c_str(),
@@ -141,7 +141,7 @@ ostream& operator<<( ostream& os, const parseData& pd ){
   }
   return os;
 }
-  
+
 void Parser::createParserFile( const parseData& pd ){
   const vector<string>& words = pd.words;
   const vector<string>& heads = pd.heads;
@@ -150,8 +150,8 @@ void Parser::createParserFile( const parseData& pd ){
   ofstream anaFile( fileName.c_str() );
   if ( anaFile ){
     for( size_t i = 0; i < words.size(); ++i ){
-      anaFile << i+1 << "\t" << words[i] << "\t" << "*" << "\t" << heads[i] 
-	      << "\t" << heads[i] << "\t" << mods[i] << "\t"<< "0" 
+      anaFile << i+1 << "\t" << words[i] << "\t" << "*" << "\t" << heads[i]
+	      << "\t" << heads[i] << "\t" << mods[i] << "\t"<< "0"
 	      << "\t" << "_" << "\t" << "_" << "\t" << "_" << endl;
     }
   }
@@ -169,8 +169,6 @@ bool Parser::init( const Configuration& configuration ){
   string relsFileName;
   string relsOptions = "-a1 +D +vdb+di";
   PI = new PythonInterface();
-  parseLog = new LogStream( theErrLog );
-  parseLog->addmessage("parser-");
   maxDepSpanS = "20";
   maxDepSpan = 20;
   bool problem = false;
@@ -261,7 +259,7 @@ bool Parser::init( const Configuration& configuration ){
   }
   if ( problem )
     return false;
-  
+
   bool happy = true;
   pairs = new Timbl::TimblAPI( pairsOptions );
   if ( pairs->Valid() ){
@@ -299,7 +297,7 @@ Parser::~Parser(){
   delete PI;
 }
 
-static vector<Word *> lookup( Word *word, 
+static vector<Word *> lookup( Word *word,
 			      const vector<Entity*>& entities ){
   vector<Word*> vec;
   for ( size_t p=0; p < entities.size(); ++p ){
@@ -327,7 +325,7 @@ void Parser::createPairs( const parseData& pd ){
       ps << "__ " << words[0] << " __"
 	 << " ROOT ROOT ROOT __ " << heads[0]
 	 << " __ ROOT ROOT ROOT "
-	 << words[0] << "^ROOT ROOT ROOT ROOT^" 
+	 << words[0] << "^ROOT ROOT ROOT ROOT^"
 	 << heads[0]
 	 << " _" << endl;
     }
@@ -357,12 +355,12 @@ void Parser::createPairs( const parseData& pd ){
 	}
 	ps << word_1 << " " << word0 << " " << word1
 	   << " ROOT ROOT ROOT "
-	   << tag_1 << " " << tag0 << " " << tag1 
+	   << tag_1 << " " << tag0 << " " << tag1
 	   << " ROOT ROOT ROOT "
 	   << tag0 << "^ROOT ROOT ROOT ROOT^" << mods0
 	   << " _" << endl;
       }
-      // 
+      //
       for ( size_t wPos=0; wPos < words.size(); ++wPos ){
 	string w_word_1, w_word0, w_word1;
 	string w_tag_1, w_tag0, w_tag1;
@@ -394,11 +392,11 @@ void Parser::createPairs( const parseData& pd ){
 	    continue;
 	  if ( wPos > maxDepSpan + pos )
 	    continue;
-	  
+
 	  ps << w_word_1;
 	  ps << " " << w_word0;
 	  ps << " " << w_word1;
-	  
+
 	  if ( pos == 0 )
 	    ps << " __";
 	  else
@@ -426,13 +424,13 @@ void Parser::createPairs( const parseData& pd ){
 	    ps << " " << heads[pos+1];
 	  else
 	    ps << " __";
-	  
+
 	  ps << " " << w_tag0 << "^";
 	  if ( pos < words.size() )
 	    ps << heads[pos];
 	  else
 	    ps << "__";
-	  
+
 	  if ( wPos > pos )
 	    ps << " LEFT " << wPos - pos;
 	  else
@@ -831,7 +829,7 @@ void Parser::prepareParse( const vector<Word *>& fwords,
       pd.mwus.push_back( vec );
     }
   }
-  
+
   createParserFile( pd );
 
 #pragma omp parallel sections
@@ -849,6 +847,7 @@ void Parser::prepareParse( const vector<Word *>& fwords,
 
 void appendParseResult( const vector<Word *>& words,
 			parseData& pd,
+			const string& tagset,
 			istream& is ){
   string line;
   int cnt=0;
@@ -859,26 +858,30 @@ void appendParseResult( const vector<Word *>& words,
     int num = TiCC::split_at( line, parts, " " );
     if ( num > 7 ){
       if ( TiCC::stringTo<int>( parts[0] ) != cnt+1 ){
-	*Log(theErrLog) << "confused! " << endl;
-	*Log(theErrLog) << "got line '" << line << "'" << endl;
+        //WARNING: commented out because theErrLog no longer available publicly
+        //*Log(theErrLog) << "confused! " << endl;
+        //*Log(theErrLog) << "got line '" << line << "'" << endl;
       }
       nums.push_back( TiCC::stringTo<int>(parts[6]) );
       roles.push_back( parts[7] );
     }
     ++cnt;
   }
-  DependenciesLayer *dl = new DependenciesLayer();
-  Sentence *sent;
+  Sentence *sent = words[0]->sentence();
+  KWargs args;
+  args["generate_id"] = sent->id();
+  args["set"] = tagset;
+  DependenciesLayer *dl = new DependenciesLayer(sent->doc(),args);
 #pragma omp critical(foliaupdate)
   {
-    sent = words[0]->sentence();
     sent->append( dl );
   }
   for ( size_t i=0; i < nums.size(); ++i ){
     if ( nums[i] != 0 ){
       KWargs args;
-      args["generate-id"] = sent->id();
+      args["generate_id"] = dl->id();
       args["class"] = roles[i];
+      args["set"] = tagset;
 #pragma omp critical(foliaupdate)
       {
 	Dependency *d = new Dependency( sent->doc(), args );
@@ -913,7 +916,7 @@ void Parser::Parse( const vector<Word*>& words, const string& mwuSet,
     *Log(parseLog) << "unable to parse an analisis without words" << endl;
     return;
   }
-  string resFileName = fileName + ".result"; 
+  string resFileName = fileName + ".result";
   string pairsInName = fileName +".pairs.inst";
   string pairsOutName = fileName +".pairs.out";
   string dirInName = fileName + ".dir.inst";
@@ -922,7 +925,7 @@ void Parser::Parse( const vector<Word*>& words, const string& mwuSet,
   string relsOutName = fileName + ".rels.out";
   remove( resFileName.c_str() );
   timers.prepareTimer.start();
-  parseData pd;  
+  parseData pd;
   prepareParse( words, mwuSet, pd );
   timers.prepareTimer.stop();
 #pragma omp parallel sections
@@ -966,7 +969,7 @@ void Parser::Parse( const vector<Word*>& words, const string& mwuSet,
   timers.csiTimer.stop();
   ifstream resFile( resFileName.c_str() );
   if ( resFile ){
-    appendParseResult( words, pd, resFile );
+    appendParseResult( words, pd, tagset, resFile );
   }
   else
     *Log(parseLog) << "couldn't open results file: " << resFileName << endl;
