@@ -1,12 +1,12 @@
 /*
-  $Id: cgn_tagger_mod.cxx 15912 2013-04-03 14:04:30Z sloot $
+  $Id: cgn_tagger_mod.cxx 17992 2015-01-21 14:07:56Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/Frog/trunk/src/cgn_tagger_mod.cxx $
 
-  Copyright (c) 2006 - 2013
+  Copyright (c) 2006 - 2015
   Tilburg University
 
   A Tagger-Lemmatizer-Morphological-Analyzer-Dependency-Parser for Dutch
- 
+
   This file is part of frog
 
   frog is free software; you can redistribute it and/or modify
@@ -29,19 +29,22 @@
 */
 
 #include "mbt/MbtAPI.h"
+#include "ucto/unicode.h"
 #include "frog/Frog.h"
 #include "frog/cgn_tagger_mod.h"
 
 using namespace std;
 using namespace folia;
 
-CGNTagger::CGNTagger(){
+CGNTagger::CGNTagger(TiCC::LogStream * logstream){
   tagger = 0;
-  cgnLog = new LogStream( theErrLog, "cgn-tagger-" );
+  filter = 0;
+  cgnLog = new LogStream( logstream, "cgn-tagger-" );
 }
 
 CGNTagger::~CGNTagger(){
   delete tagger;
+  delete filter;
   delete cgnLog;
 }
 
@@ -52,24 +55,24 @@ void fillSubSetTable(){
   // should become a config file!
   cgnSubSets.insert( make_pair("soort", "ntype" ));
   cgnSubSets.insert( make_pair("eigen", "ntype" ));
-  
+
   cgnSubSets.insert( make_pair("ev", "getal" ));
   cgnSubSets.insert( make_pair("mv", "getal" ));
   cgnSubSets.insert( make_pair("getal", "getal" ));
-  
+
   cgnSubSets.insert( make_pair("zijd", "genus" ));
   cgnSubSets.insert( make_pair("onz", "genus" ));
   cgnSubSets.insert( make_pair("masc", "genus" ));
   cgnSubSets.insert( make_pair("fem", "genus" ));
   cgnSubSets.insert( make_pair("genus", "genus" ) );
-  
+
   cgnSubSets.insert( make_pair("stan", "naamval" ));
   cgnSubSets.insert( make_pair("gen", "naamval" ));
   cgnSubSets.insert( make_pair("dat", "naamval" ));
   cgnSubSets.insert( make_pair("nomin", "naamval" ));
   cgnSubSets.insert( make_pair("obl", "naamval" ));
   cgnSubSets.insert( make_pair("bijz", "naamval" ));
-    
+
   cgnSubSets.insert( make_pair("afgebr", "spectype" ));
   cgnSubSets.insert( make_pair("afk", "spectype" ));
   cgnSubSets.insert( make_pair("deeleigen", "spectype" ));
@@ -80,14 +83,14 @@ void fillSubSetTable(){
   cgnSubSets.insert( make_pair("achter", "spectype" ));
   cgnSubSets.insert( make_pair("comment", "spectype" ));
   cgnSubSets.insert( make_pair("onverst", "spectype" ));
-  
+
   cgnSubSets.insert( make_pair("neven", "conjtype" ));
   cgnSubSets.insert( make_pair("onder", "conjtype" ));
-    
+
   cgnSubSets.insert( make_pair("init", "vztype" ));
   cgnSubSets.insert( make_pair("versm", "vztype" ));
   cgnSubSets.insert( make_pair("fin", "vztype" ));
-    
+
   cgnSubSets.insert( make_pair("agr", "npagr" ));
   cgnSubSets.insert( make_pair("evon", "npagr" ));
   cgnSubSets.insert( make_pair("rest", "npagr" ));
@@ -96,10 +99,10 @@ void fillSubSetTable(){
   cgnSubSets.insert( make_pair( "evmo", "npagr" ));
   cgnSubSets.insert( make_pair( "rest3", "npagr" ));
   cgnSubSets.insert( make_pair("evf", "npagr" ));
-  
+
   cgnSubSets.insert( make_pair("bep", "lwtype" ));
   cgnSubSets.insert( make_pair("onbep", "lwtype" ));
-  
+
   cgnSubSets.insert( make_pair("pers", "vwtype" ));
   cgnSubSets.insert( make_pair("pr", "vwtype" ));
   cgnSubSets.insert( make_pair("refl", "vwtype" ));
@@ -111,16 +114,16 @@ void fillSubSetTable(){
   cgnSubSets.insert( make_pair("excl", "vwtype" ));
   cgnSubSets.insert( make_pair("aanw", "vwtype" ));
   cgnSubSets.insert( make_pair("onbep", "vwtype" ));
-    
+
   cgnSubSets.insert( make_pair("adv-pron", "pdtype" ));
   cgnSubSets.insert( make_pair("pron", "pdtype" ));
   cgnSubSets.insert( make_pair("det", "pdtype" ));
   cgnSubSets.insert( make_pair("grad", "pdtype" ));
-  
+
   cgnSubSets.insert( make_pair("vol", "status" ));
   cgnSubSets.insert( make_pair("red", "status" ));
   cgnSubSets.insert( make_pair("nadr", "status" ));
-  
+
   cgnSubSets.insert( make_pair("1", "persoon" ));
   cgnSubSets.insert( make_pair("2", "persoon" ));
   cgnSubSets.insert( make_pair("2v", "persoon" ));
@@ -131,41 +134,41 @@ void fillSubSetTable(){
   cgnSubSets.insert( make_pair("3v", "persoon" ));
   cgnSubSets.insert( make_pair("3o", "persoon" ));
   cgnSubSets.insert( make_pair("persoon", "persoon" ));
-  
+
   cgnSubSets.insert( make_pair("prenom", "positie" ));
   cgnSubSets.insert( make_pair("postnom", "positie" ));
   cgnSubSets.insert( make_pair("nom", "positie" ));
   cgnSubSets.insert( make_pair("vrij", "positie" ));
-  
+
   cgnSubSets.insert( make_pair("zonder", "buiging" ));
   cgnSubSets.insert( make_pair("met-e", "buiging" ));
   cgnSubSets.insert( make_pair("met-s", "buiging" ));
-    
+
   cgnSubSets.insert( make_pair("zonder-v", "getal-n" ));
   cgnSubSets.insert( make_pair("mv-n", "getal-n" ));
   cgnSubSets.insert( make_pair("zonder-n", "getal-n" ));
-    
+
   cgnSubSets.insert( make_pair("basis", "graad" ));
   cgnSubSets.insert( make_pair("comp", "graad" ));
   cgnSubSets.insert( make_pair("sup", "graad" ));
   cgnSubSets.insert( make_pair("dim", "graad" ));
-  
+
   cgnSubSets.insert( make_pair("pv", "wvorm" ));
   cgnSubSets.insert( make_pair("inf", "wvorm" ));
   cgnSubSets.insert( make_pair("vd", "wvorm" ));
   cgnSubSets.insert( make_pair("od", "wvorm" ));
-    
+
   cgnSubSets.insert( make_pair("tgw", "pvtijd" ));
   cgnSubSets.insert( make_pair("verl", "pvtijd" ));
   cgnSubSets.insert( make_pair("conj", "pvtijd" ));
-  
+
   cgnSubSets.insert( make_pair("ev", "pvagr" ));
   cgnSubSets.insert( make_pair("mv", "pvagr" ));
   cgnSubSets.insert( make_pair( "met-t", "pvagr" ));
-    
+
   cgnSubSets.insert( make_pair("hoofd", "numtype" ));
   cgnSubSets.insert( make_pair("rang", "numtype" ));
-  
+
   cgnSubSets.insert( make_pair("dial", "dial" ));
 
   cgnConstraints.insert( make_pair( "getal", "N" ) );
@@ -173,12 +176,16 @@ void fillSubSetTable(){
   cgnConstraints.insert( make_pair( "pvagr", "WW" ) );
 }
 
- 
-bool CGNTagger::init( const Configuration& conf ){
-  debug = tpDebug;
-  string db = conf.lookUp( "debug", "tagger" );
-  if ( !db.empty() )
-    debug = TiCC::stringTo<int>( db );
+
+bool CGNTagger::init( const Configuration& config ){
+  debug = 0;
+  string val = config.lookUp( "debug", "tagger" );
+  if ( val.empty() ){
+    val = config.lookUp( "debug" );
+  }
+  if ( !val.empty() ){
+    debug = TiCC::stringTo<int>( val );
+  }
   switch ( debug ){
   case 0:
   case 1:
@@ -195,12 +202,12 @@ bool CGNTagger::init( const Configuration& conf ){
     break;
   default:
     cgnLog->setlevel(LogExtreme);
-  }    
+  }
   if ( tagger != 0 ){
     *Log(cgnLog) << "CGNTagger is already initialized!" << endl;
     return false;
-  }  
-  string val = conf.lookUp( "settings", "tagger" );
+  }
+  val = config.lookUp( "settings", "tagger" );
   if ( val.empty() ){
     *Log(cgnLog) << "Unable to find settings for Tagger" << endl;
     return false;
@@ -209,21 +216,29 @@ bool CGNTagger::init( const Configuration& conf ){
   if ( val[0] == '/' ) // an absolute path
     settings = val;
   else
-    settings =  configuration.configDir() + val;
+    settings =  config.configDir() + val;
 
-  val = conf.lookUp( "version", "tagger" );
+  val = config.lookUp( "version", "tagger" );
   if ( val.empty() ){
     version = "1.0";
   }
   else
     version = val;
-  val = conf.lookUp( "set", "tagger" );
+  val = config.lookUp( "set", "tagger" );
   if ( val.empty() ){
     tagset = "http://ilk.uvt.nl/folia/sets/frog-mbpos-cgn";
   }
   else
     tagset = val;
   fillSubSetTable();
+  string charFile = config.lookUp( "char_filter_file", "tagger" );
+  if ( charFile.empty() )
+    charFile = config.lookUp( "char_filter_file" );
+  if ( !charFile.empty() ){
+    charFile = prefix( config.configDir(), charFile );
+    filter = new Tokenizer::UnicodeFilter();
+    filter->fill( charFile );
+  }
   string init = "-s " + settings + " -vcf";
   tagger = new MbtAPI( init, *cgnLog );
   return tagger->isInit();
@@ -253,7 +268,7 @@ string getSubSet( const string& val, const string& head ){
     }
     ++it;
   }
-  throw folia::ValueError( "unable to find cgn subset for class: '" + val + 
+  throw folia::ValueError( "unable to find cgn subset for class: '" + val +
 			   "' whithin the constraints for '" + head + "'" );
 }
 
@@ -263,8 +278,10 @@ void CGNTagger::addTag( Word *word, const string& inputTag, double confidence ){
   string tagPartS;
   string ucto_class = word->cls();
   if ( debug )
-    *Log(cgnLog) << "ucto class= " << ucto_class << endl;
-  if ( ucto_class == "PUNCTUATION" && cgnTag.find("SPEC(") != string::npos ){
+    *Log(cgnLog) << "ucto class= " << ucto_class << " cgnTag=" << cgnTag << endl;
+  if ( ucto_class == "PUNCTUATION"
+       && ( cgnTag.find("SPEC(") != string::npos
+	    || cgnTag.find("LET") != string::npos ) ){
     mainTag = "LET";
     tagPartS = "";
     cgnTag = "LET()";
@@ -278,6 +295,7 @@ void CGNTagger::addTag( Word *word, const string& inputTag, double confidence ){
   }
   else if ( ucto_class == "SMILEY" ||
 	    ucto_class == "REVERSE-SMILEY" ||
+	    ucto_class == "EMOTICON" ||
 	    ucto_class.find("URL") == 0 ||
 	    ucto_class == "E-MAIL" ){
     mainTag = "SPEC";
@@ -289,7 +307,7 @@ void CGNTagger::addTag( Word *word, const string& inputTag, double confidence ){
     string::size_type openH = cgnTag.find( '(' );
     string::size_type closeH = cgnTag.find( ')' );
     if ( openH == string::npos || closeH == string::npos ){
-      *Log(theErrLog) << "tagger_mod: main tag without subparts: impossible: " << cgnTag << endl;
+      *Log(cgnLog) << "tagger_mod: main tag without subparts: impossible: " << cgnTag << endl;
       exit(-1);
     }
     mainTag = cgnTag.substr( 0, openH );
@@ -337,15 +355,16 @@ vector<TagResult> CGNTagger::tagLine( const string& line ){
 
 void CGNTagger::Classify( const vector<Word*>& swords ){
   if ( !swords.empty() ) {
-    vector<string> words;
     string sentence; // the tagger needs the whole sentence
     for ( size_t w = 0; w < swords.size(); ++w ) {
-      sentence += swords[w]->str();
-      words.push_back( swords[w]->str() );
+      UnicodeString word = swords[w]->text();
+      if ( filter )
+	word = filter->filter( word );
+      sentence += UnicodeToUTF8(word);
       if ( w < swords.size()-1 )
 	sentence += " ";
     }
-    if (debug) 
+    if (debug)
       *Log(cgnLog) << "CGN tagger in: " << sentence << endl;
     vector<TagResult> tagv = tagger->TagLine(sentence);
     if ( tagv.size() != swords.size() ){
@@ -354,7 +373,7 @@ void CGNTagger::Classify( const vector<Word*>& swords ){
       for ( size_t w = 0; w < swords.size(); ++w ) {
 	*Log(cgnLog) << "w[" << w << "]= " << swords[w]->str() << endl;
       }
-      *Log(cgnLog) << "words according to CGN tagger: " << endl;    
+      *Log(cgnLog) << "words according to CGN tagger: " << endl;
       for ( size_t i=0; i < tagv.size(); ++i ){
 	*Log(cgnLog) << "word[" << i << "]=" << tagv[i].word() << endl;
       }
@@ -363,8 +382,8 @@ void CGNTagger::Classify( const vector<Word*>& swords ){
     if ( debug ){
       *Log(cgnLog) << "CGN tagger out: " << endl;
       for ( size_t i=0; i < tagv.size(); ++i ){
-	*Log(cgnLog) << "[" << i << "] : word=" << tagv[i].word() 
-		     << " tag=" << tagv[i].assignedTag() 
+	*Log(cgnLog) << "[" << i << "] : word=" << tagv[i].word()
+		     << " tag=" << tagv[i].assignedTag()
 		     << " confidence=" << tagv[i].confidence() << endl;
       }
     }
