@@ -1,36 +1,37 @@
 /*
-  $Id: mblem_mod.cxx 15912 2013-04-03 14:04:30Z sloot $
+  $Id: mblem_mod.cxx 17992 2015-01-21 14:07:56Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/Frog/trunk/src/mblem_mod.cxx $
 
-  Copyright (c) 2006 - 2013
+  Copyright (c) 2006 - 2015
   Tilburg University
 
   This file is part of frog.
 
   frog is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by  
-  the Free Software Foundation; either version 3 of the License, or  
-  (at your option) any later version.  
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
 
   frog is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of  
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
-  GNU General Public License for more details.  
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-  You should have received a copy of the GNU General Public License  
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.  
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
   For questions and suggestions, see:
       http://ilk.uvt.nl/software.html
   or send mail to:
       timbl@uvt.nl
-*/                                                                   
+*/
 
 #include <cstdlib>
 #include <string>
 #include <iostream>
 #include <fstream>
 #include "timbl/TimblAPI.h"
+#include "ucto/unicode.h"
 #include "ticcutils/LogStream.h"
 #include "ticcutils/Configuration.h"
 #include "frog/Frog.h"
@@ -40,15 +41,19 @@ using namespace std;
 using namespace TiCC;
 using namespace folia;
 
-Mblem::Mblem(): myLex(0),punctuation( "?...,:;\\'`(){}[]%#+-_=/!" ), 
-		history(20), debug(0) {
-  mblemLog = new LogStream( theErrLog, "mblem" );
+Mblem::Mblem( LogStream *logstream ):
+  myLex(0),
+  punctuation( "?...,:;\\'`(){}[]%#+-_=/!" ),
+  history(20),
+  debug(0)
+{
+  mblemLog = new LogStream( logstream, "mblem" );
 }
 
 void Mblem::read_transtable( const string& tableName ) {
   ifstream bron( tableName.c_str() );
   if ( !bron ) {
-    *Log(mblemLog) << "translation table file '" << tableName 
+    *Log(mblemLog) << "translation table file '" << tableName
 		    << "' appears to be missing." << endl;
     exit(1);
   }
@@ -64,7 +69,7 @@ void Mblem::read_transtable( const string& tableName ) {
       classMap[classCode] = className;
     }
     // else {
-    //   *Log(mblemLog) << "multiple entry " << className << " " << classCode << " in translation table file: " << tableName  << " (Ignored) " << endl;      
+    //   *Log(mblemLog) << "multiple entry " << className << " " << classCode << " in translation table file: " << tableName  << " (Ignored) " << endl;
     // }
     bron >> ws;
   }
@@ -73,11 +78,15 @@ void Mblem::read_transtable( const string& tableName ) {
 
 bool Mblem::init( const Configuration& config ) {
   *Log(mblemLog) << "Initiating lemmatizer..." << endl;
-  debug = tpDebug;
-  string db = config.lookUp( "debug", "mblem" );
-  if ( !db.empty() )
-    debug = TiCC::stringTo<int>( db );
-  string val = config.lookUp( "version", "mblem" );
+  debug = 0;
+  string val = config.lookUp( "debug", "mblem" );
+  if ( val.empty() ){
+    val = config.lookUp( "debug" );
+  }
+  if ( !val.empty() ){
+    debug = TiCC::stringTo<int>( val );
+  }
+  val = config.lookUp( "version", "mblem" );
   if ( val.empty() ){
     version = "1.0";
   }
@@ -96,7 +105,7 @@ bool Mblem::init( const Configuration& config ) {
   }
   else
     cgn_tagset = val;
-  
+
   string transName = config.lookUp( "transFile", "mblem" );
   if ( !transName.empty() ){
     transName = prefix( config.configDir(), transName );
@@ -106,11 +115,21 @@ bool Mblem::init( const Configuration& config ) {
   if ( treeName.empty() )
     treeName = "mblem.tree";
   treeName = prefix( config.configDir(), treeName );
+
+  string charFile = config.lookUp( "char_filter_file", "mblem" );
+  if ( charFile.empty() )
+    charFile = config.lookUp( "char_filter_file" );
+  if ( !charFile.empty() ){
+    charFile = prefix( config.configDir(), charFile );
+    filter = new Tokenizer::UnicodeFilter();
+    filter->fill( charFile );
+  }
+
   string opts = config.lookUp( "timblOpts", "mblem" );
   if ( opts.empty() )
     opts = "-a1";
   //make it silent
-  opts += " +vs -vf";	    
+  opts += " +vs -vf";
   //Read in (igtree) data
   myLex = new Timbl::TimblAPI(opts);
   return myLex->GetInstanceBase(treeName);
@@ -118,6 +137,7 @@ bool Mblem::init( const Configuration& config ) {
 
 Mblem::~Mblem(){
   //    *Log(mblemLog) << "cleaning up MBLEM stuff" << endl;
+  delete filter;
   delete myLex;
   myLex = 0;
   delete mblemLog;
@@ -128,9 +148,8 @@ string Mblem::make_instance( const UnicodeString& in ) {
     *Log(mblemLog) << "making instance from: " << in << endl;
   UnicodeString instance = "";
   size_t length = in.length();
-  size_t j;
   for ( size_t i=0; i < history; i++) {
-    j = length - history + i;
+    size_t j = length - history + i;
     if (( i < history - length ) &&
 	(length<history))
       instance += "= ";
@@ -143,7 +162,7 @@ string Mblem::make_instance( const UnicodeString& in ) {
   string result = UnicodeToUTF8(instance);
   if (debug)
     *Log(mblemLog) << "inst: " << instance << endl;
-  
+
   return result;
 }
 
@@ -155,7 +174,7 @@ bool similar( const string& tag, const string& lookuptag,
 
 bool isSimilar( const string& tag, const string& cgnTag ){
   // Dutch CGN constraints
-  return 
+  return
     tag == cgnTag ||
     similar( tag, cgnTag, "hulpofkopp" ) ||
     similar( tag, cgnTag, "neut,zelfst" ) ||
@@ -180,38 +199,35 @@ bool isSimilar( const string& tag, const string& cgnTag ){
     similar( tag, cgnTag, "ovt,1,ev" );
 }
 
-void Mblem::addLemma( FoliaElement *word, const string& cls ){
+void Mblem::addLemma( Word *word, const string& cls ){
   KWargs args;
   args["set"]=tagset;
   args["cls"]=cls;
 #pragma omp critical(foliaupdate)
   {
-    word->addLemmaAnnotation( args );
+    try {
+      word->addLemmaAnnotation( args );
+    }
+    catch( const exception& e ){
+      *Log(mblemLog) << e.what() << " addLemma failed." << endl;
+      exit(EXIT_FAILURE);
+    }
   }
 }
-  
-void Mblem::addAltLemma( Word *word, const string& cls ){
-  Alternative *alt = new Alternative();
-#pragma omp critical(foliaupdate)
-  {
-    word->append( alt );
-  }
-  addLemma( alt, cls );
-}
-  
+
 void Mblem::filterTag( const string& postag ){
   vector<mblemData>::iterator it = mblemResult.begin();
   while( it != mblemResult.end() ){
-    if (debug)
-      *Log(mblemLog) << "compare cgn-tag " << postag << " with " << it->getTag() << " ";
     if ( isSimilar( postag, it->getTag() ) ){
       if ( debug )
-	*Log(mblemLog) << "similar! " << endl;
+	*Log(mblemLog) << "compare cgn-tag " << postag << " with "
+		       << it->getTag() << " similar! " << endl;
       ++it;
     }
     else {
       if ( debug )
-	*Log(mblemLog) << "NOT similar! " << endl;	
+	*Log(mblemLog) << "compare cgn-tag " << postag << " with "
+		       << it->getTag() << " NOT similar! " << endl;
       it = mblemResult.erase(it);
     }
   }
@@ -234,12 +250,19 @@ void Mblem::makeUnique( ){
       }
       else {
 	if ( debug )
-	  *Log(mblemLog) << "NOT equal! " << endl;	
+	  *Log(mblemLog) << "NOT equal! " << endl;
 	++it2;
       }
     }
     ++it;
   }
+  if (debug){
+    *Log(mblemLog) << "final result after filter and unique" << endl;
+    for( size_t index=0; index < mblemResult.size(); ++index ){
+      *Log(mblemLog) << "lemma alt: " << mblemResult[index].getLemma()
+		     << "\ttag alt: " << mblemResult[index].getTag() << endl;
+    }
+  }
 }
 
 void Mblem::getFoLiAResult( Word *word, const UnicodeString& uWord ){
@@ -249,26 +272,18 @@ void Mblem::getFoLiAResult( Word *word, const UnicodeString& uWord ){
     addLemma( word, result );
   }
   else {
-    bool first = true;
     vector<mblemData>::iterator it = mblemResult.begin();
     while( it != mblemResult.end() ){
       string result = it->getLemma();
-      if ( first ){
-	addLemma( word, result );
-	first = false;
-      }
-      else {
-	// there are more matching lemmas. add them as alternatives
-	addAltLemma( word, result );
-      }
+      addLemma( word, result );
       ++it;
     }
   }
-} 
+}
 
 
 void Mblem::addDeclaration( Document& doc ) const {
-  doc.declare( AnnotationType::LEMMA, 
+  doc.declare( AnnotationType::LEMMA,
 	       tagset,
 	       "annotator='frog-mblem-" + version
 	       + "', annotatortype='auto', datetime='" + getTime() + "'");
@@ -277,30 +292,54 @@ void Mblem::addDeclaration( Document& doc ) const {
 void Mblem::Classify( Word *sword ){
   if ( sword->isinstance(PlaceHolder_t ) )
     return;
-  string word;
+  UnicodeString word;
   string tag;
   string pos;
+  string token_class;
 #pragma omp critical(foliaupdate)
-  {  
-    word = sword->str();
+  {
+    word = sword->text();
     pos = sword->pos();
+    token_class = sword->cls();
     tag = sword->annotation<PosAnnotation>( cgn_tagset )->feat("head");
   }
-  if ( tag == "SPEC" || tag == "LET" ) {
-    addLemma( sword, word );
+  if (debug)
+    *Log(mblemLog) << "Classify " << word << "(" << pos << ") ["
+		   << token_class << "]" << endl;
+  if ( filter )
+    word = filter->filter( word );
+  if ( tag == "LET" ){
+    addLemma( sword, UnicodeToUTF8(word) );
     return;
   }
-  UnicodeString uWord = UTF8ToUnicode(word);
-  uWord.toLower();
-  Classify( uWord );
-  filterTag( pos ); 
-  makeUnique(); 
-  getFoLiAResult( sword, uWord ); 
+  else if ( tag == "SPEC" ){
+    if ( pos.find("eigen") != string::npos ){
+      // SPEC(deeleigen) might contain suffixes
+      if ( token_class == "QUOTE-SUFFIX" ){
+	addLemma( sword, UnicodeToUTF8(UnicodeString( word, 0, word.length()-1)));
+      }
+      else if ( token_class == "WORD-WITHSUFFIX" ){
+	addLemma( sword, UnicodeToUTF8(UnicodeString( word, 0, word.length()-2)));
+      }
+      else {
+	addLemma( sword, UnicodeToUTF8(word) );      return;
+      }
+    }
+    else
+      addLemma( sword, UnicodeToUTF8(word) );
+    return;
+  }
+  if ( tag != "SPEC")
+    word.toLower();
+  Classify( word );
+  filterTag( pos );
+  makeUnique();
+  getFoLiAResult( sword, word );
 }
 
 void Mblem::Classify( const UnicodeString& uWord ){
   mblemResult.clear();
-  string inst = make_instance(uWord);  
+  string inst = make_instance(uWord);
   string classString;
   myLex->Classify( inst, classString );
   if (debug)
@@ -313,11 +352,11 @@ void Mblem::Classify( const UnicodeString& uWord ){
   }
   int index = 0;
   while ( index < numParts ) {
-    string partS = parts[index++]; 
+    string partS = parts[index++];
     UnicodeString lemma;
     string restag;
     string::size_type pos = partS.find("+");
-    if ( pos == string::npos ){ 
+    if ( pos == string::npos ){
       // nothing to edit
       restag = partS;
       lemma = uWord;
@@ -351,10 +390,10 @@ void Mblem::Classify( const UnicodeString& uWord ){
       if (debug){
 	*Log(mblemLog) << "pre-prefix word: '" << uWord << "' prefix: '"
 		       << prefix << "'" << endl;
-      }	
+      }
       int prefixpos = 0;
       if ( !prefix.isEmpty() ) {
-	// Whenever Toads makemblem is improved, (the infamous 
+	// Whenever Toads makemblem is improved, (the infamous
 	// 'tegemoetgekomen' example), this should probably
 	// become prefixpos = uWord.lastIndexOf(prefix);
 	prefixpos = uWord.indexOf(prefix);
@@ -366,7 +405,7 @@ void Mblem::Classify( const UnicodeString& uWord ){
 	  prefix.remove();
 	}
       }
-      
+
       if (debug)
 	*Log(mblemLog) << "prefixpos = " << prefixpos << endl;
       if (prefixpos >= 0) {
@@ -374,13 +413,13 @@ void Mblem::Classify( const UnicodeString& uWord ){
 	prefixpos = prefixpos + prefix.length();
       }
       if (debug)
-	*Log(mblemLog) << "post word: "<< uWord 
+	*Log(mblemLog) << "post word: "<< uWord
 		       << " lemma: " << lemma
 		       << " prefix: " << prefix
 		       << " delstr: " << delstr
 		       << " insstr: " << insstr
 		       << endl;
-      
+
       if ( uWord.endsWith( delstr ) ){
 	if ( uWord.length() > delstr.length() ){
 	  // chop delstr from the back, but do not delete the whole word
@@ -417,7 +456,7 @@ void Mblem::Classify( const UnicodeString& uWord ){
 	  *Log(mblemLog) << "found " << restag << endl;
       }
       else
-	*Log(mblemLog) << "problem: found no translation for " 
+	*Log(mblemLog) << "problem: found no translation for "
 		       << restag << " using it 'as-is'" << endl;
     }
     if ( debug )
