@@ -1,12 +1,12 @@
 /*
-  $Id: ucto_tokenizer_mod.cxx 15833 2013-03-28 12:10:55Z sloot $
+  $Id: ucto_tokenizer_mod.cxx 17992 2015-01-21 14:07:56Z sloot $
   $URL: https://ilk.uvt.nl/svn/sources/Frog/trunk/src/ucto_tokenizer_mod.cxx $
 
-  Copyright (c) 2006 - 2013
+  Copyright (c) 2006 - 2015
   Tilburg University
 
   A Tagger-Lemmatizer-Morphological-Analyzer-Dependency-Parser for Dutch
- 
+
   This file is part of frog
 
   frog is free software; you can redistribute it and/or modify
@@ -38,32 +38,30 @@
 using namespace std;
 using namespace TiCC;
 
-UctoTokenizer::UctoTokenizer() {
-  tokenizer = 0; 
-  uctoLog = new LogStream( theErrLog, "tok-" );
-};
+UctoTokenizer::UctoTokenizer(LogStream * logstream) {
+  tokenizer = 0;
+  uctoLog = new LogStream( logstream, "tok-" );
+}
 
-bool UctoTokenizer::init( const Configuration& conf, const string & docid, bool pass ){
+bool UctoTokenizer::init( const Configuration& config ){
   if ( tokenizer )
-    throw runtime_error( "ucto tokenizer is already initalized" );
+    throw runtime_error( "ucto tokenizer is already initialized" );
   tokenizer = new Tokenizer::TokenizerClass();
   tokenizer->setErrorLog( uctoLog );
-  string debug = conf.lookUp( "debug", "tokenizer" );
-  if ( debug.empty() ){
-    debug = conf.lookUp( "debug" );
+  int debug = 0;
+  string val = config.lookUp( "debug", "tokenizer" );
+  if ( val.empty() ){
+    val = config.lookUp( "debug" );
   }
-  if ( debug.empty() ){
-    tokenizer->setDebug( tpDebug );
-  }
-  else
-    tokenizer->setDebug( TiCC::stringTo<int>(debug) );
-  if ( pass ){
+  if ( !val.empty() )
+    debug = TiCC::stringTo<int>( val );
+  tokenizer->setDebug( debug );
+  if ( tokenizer->getPassThru() ){
     // when passthru, we don't further initialize the tokenizer
     // it wil run in minimal mode then.
-    tokenizer->setPassThru( true ); 
   }
   else {
-    string rulesName = conf.lookUp( "rulesFile", "tokenizer" );
+    string rulesName = config.lookUp( "rulesFile", "tokenizer" );
     if ( rulesName.empty() ){
       *Log(uctoLog) << "no rulesFile found in configuration" << endl;
       return false;
@@ -76,33 +74,33 @@ bool UctoTokenizer::init( const Configuration& conf, const string & docid, bool
   tokenizer->setEosMarker( "" );
   tokenizer->setVerbose( false );
   tokenizer->setSentenceDetection( true ); //detection of sentences
-  tokenizer->setParagraphDetection( false ); //detection of paragraphs  
-  tokenizer->setXMLOutput( true, docid );
+  tokenizer->setParagraphDetection( false ); //detection of paragraphs
+  tokenizer->setXMLOutput( true );
   return true;
 }
 
 void UctoTokenizer::setUttMarker( const string& u ) {
   if ( tokenizer ){
     if ( !u.empty() )
-      tokenizer->setEosMarker( u ); 
+      tokenizer->setEosMarker( u );
   }
   else
-    throw runtime_error( "ucto tokenizer not initalized" );
-};
+    throw runtime_error( "ucto tokenizer not initialized" );
+}
 
 void UctoTokenizer::setSentencePerLineInput( bool b ) {
   if ( tokenizer )
-    tokenizer->setSentencePerLineInput( b ); 
+    tokenizer->setSentencePerLineInput( b );
   else
-    throw runtime_error( "ucto tokenizer not initalized" );
-};
+    throw runtime_error( "ucto tokenizer not initialized" );
+}
 
 void UctoTokenizer::setQuoteDetection( bool b ) {
   if ( tokenizer )
-    tokenizer->setQuoteDetection( b ); 
+    tokenizer->setQuoteDetection( b );
   else
-    throw runtime_error( "ucto tokenizer not initalized" );
-};
+    throw runtime_error( "ucto tokenizer not initialized" );
+}
 
 void UctoTokenizer::setInputEncoding( const std::string & enc ){
   if ( tokenizer ){
@@ -110,7 +108,7 @@ void UctoTokenizer::setInputEncoding( const std::string & enc ){
       tokenizer->setInputEncoding( enc );
   }
   else
-    throw runtime_error( "ucto tokenizer not initalized" );
+    throw runtime_error( "ucto tokenizer not initialized" );
 }
 
 void UctoTokenizer::setTextClass( const std::string& cls ){
@@ -119,7 +117,16 @@ void UctoTokenizer::setTextClass( const std::string& cls ){
       tokenizer->setTextClass( cls );
   }
   else
-    throw runtime_error( "ucto tokenizer not initalized" );
+    throw runtime_error( "ucto tokenizer not initialized" );
+}
+
+void UctoTokenizer::setDocID( const std::string& id ){
+  if ( tokenizer ){
+    if ( !id.empty() )
+      tokenizer->setDocID( id );
+  }
+  else
+    throw runtime_error( "ucto tokenizer not initialized" );
 }
 
 void UctoTokenizer::setInputXml( bool b ){
@@ -127,11 +134,28 @@ void UctoTokenizer::setInputXml( bool b ){
     tokenizer->setXMLInput( b );
   }
   else
-    throw runtime_error( "ucto tokenizer not initalized" );
+    throw runtime_error( "ucto tokenizer not initialized" );
+}
+
+void UctoTokenizer::setPassThru( const bool b ) {
+  if ( tokenizer ){
+    tokenizer->setPassThru( b );
+  }
+  else
+    throw runtime_error( "ucto tokenizer not initialized" );
+}
+
+bool UctoTokenizer::getPassThru() const {
+  if ( tokenizer ){
+    return tokenizer->getPassThru();
+  }
+  else
+    throw runtime_error( "ucto tokenizer not initialized" );
 }
 
 vector<string> UctoTokenizer::tokenize( const string& line ){
   if ( tokenizer ){
+    tokenizer->reset();
     if ( tokenizer->getPassThru() ){
       bool bos = true;
       tokenizer->passthruLine( line, bos );
@@ -142,21 +166,29 @@ vector<string> UctoTokenizer::tokenize( const string& line ){
     return tokenizer->getSentences();
   }
   else
-    throw runtime_error( "ucto tokenizer not initalized" );
+    throw runtime_error( "ucto tokenizer not initialized" );
 }
 
 folia::Document UctoTokenizer::tokenize( istream& is ){
   if ( tokenizer )
     return tokenizer->tokenize( is );
   else
-    throw runtime_error( "ucto tokenizer not initalized" );
+    throw runtime_error( "ucto tokenizer not initialized" );
+}
+
+folia::Document UctoTokenizer::tokenizestring( const string& s){
+  if ( tokenizer) {
+    istringstream is(s);
+    return tokenizer->tokenize( is);
+  }
+  else
+    throw runtime_error( "ucto tokenizer not initialized" );
 }
 
 bool UctoTokenizer::tokenize( folia::Document& doc ){
   if ( tokenizer )
     return tokenizer->tokenize( doc );
   else
-    throw runtime_error( "ucto tokenizer not initalized" );
+    throw runtime_error( "ucto tokenizer not initialized" );
 
 }
-
